@@ -1,5 +1,4 @@
-import inspect
-from typing import Callable, Dict, List, Set, Union
+from typing import Callable, Dict, List
 
 from ..typing import T_Dispatcher
 from .decorator import Decorator
@@ -7,7 +6,7 @@ from .decorator import Decorator
 
 class ExecTarget:
     callable: Callable
-    inline_dispatchers: List[T_Dispatcher]
+    dispatchers: List[T_Dispatcher]
     decorators: List[Decorator]
 
     param_paths: Dict[str, List[T_Dispatcher]]
@@ -19,7 +18,7 @@ class ExecTarget:
         decorators: List[Decorator] = None,
     ):
         self.callable = callable
-        self.inline_dispatchers = inline_dispatchers or []
+        self.dispatchers = inline_dispatchers or []
         self.decorators = decorators or []
 
         self.param_paths = {}
